python_build: A simple, correct PEP517 package builder
======================================================

Description
-----------

``build`` is a simple, correct PEP517 package builder

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/build/

